==> attal_0.8.orig.tar.gz: attal-0.8/i18n/de/attal_client_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ClientInterface</name>
    <message>
        <source>CTRL+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Die Verbindung kann nicht hergestellt werden</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Sie sind bereits mit dem Server verbunden, bitte trennen sie die Verbindung zuvor. </translation>
    </message>
    <message>
        <source>Attal - Lords of Doom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want abandon the match ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tab Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/de/attal_client_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ClientInterface</name>
    <message>
        <source>CTRL+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Die Verbindung kann nicht hergestellt werden</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Sie sind bereits mit dem Server verbunden, bitte trennen sie die Verbindung zuvor. </translation>
    </message>
    <message>
        <source>Attal - Lords of Doom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want abandon the match ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tab Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast Server </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast &amp;Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
